import java.awt.Font;

import quadbase.common.util.internal.FontTable;
import quadbase.common.util.internal.QbUtil;
import quadbase.common.util.output.pdf.BaseFont;
import quadbase.reportdesigner.ReportAPI.QbReport;
import quadbase.reportdesigner.ReportElements.ReportCell;

public class PdfFontMappingExample {
	   public static void main(String[] args) {
		   
		   // do not connect to EspressManager
		   QbReport.setEspressManagerUsed(false);
		   
	        try {	            
	            String reportPath = "Templates/PDF_Font_Mapping_Test.pak";
	            String exportPath = "Templates/PDF_Font_Mapping_Test.pdf";
	            String fontFold = "fonts/";
	            
	            QbReport rpt = new QbReport(null, reportPath);
	            
	            // get all the report cells from Report Header
	            ReportCell[] rptcells =  rpt.getReportHeader().getCells();
	            
	            Font font = null;
	            
	            for (ReportCell rptcell: rptcells) {
	            	// PDF Font Mapping to CJK font
	            	if (rptcell.getCustomID().equals("chineseCJK")) {	            		
	            		// create a Java Font named "font001"
	    	            font = FontTable.newFont("font001", Font.BOLD, QbUtil.getAdjustedFont(14, true));
	    	            // map font named "font001" to "STSong-Light,Bold" with encoding "Adobe-GB1-0", NO embed this font to the document
	            		rpt.setFontMapping("font001", QbReport.BOLD, "STSong-Light,Bold", "Adobe-GB1-0", false);
	            		// set rptcell font to "font001"
	    	            rptcell.setFont(font);
	            	}
	            	if (rptcell.getCustomID().equals("japaneseCJK")) {
	            		font = FontTable.newFont("font002", Font.BOLD | Font.ITALIC, QbUtil.getAdjustedFont(12, true));
	            		rpt.setFontMapping("font002", QbReport.BOLDITALIC, "HeiseiMin-W3,BoldItalic", "90msp-RKSJ-H", false);
	    	            rptcell.setFont(font);
	            	}
	            	if (rptcell.getCustomID().equals("koreanCJK")) {
	            		font = FontTable.newFont("font003", Font.PLAIN, QbUtil.getAdjustedFont(12, true));
	            		rpt.setFontMapping("font003", QbReport.PLAIN, "HYGoThic-Medium", "Adobe-Korea1-2", false);
	    	            rptcell.setFont(font);
	            	}
	            	
	            	// PDF Font Mapping to font file
	            	if (rptcell.getCustomID().equals("chinese")) {
	            		// create a Java Font named "font004"
	    	            font = FontTable.newFont("font004", Font.PLAIN, QbUtil.getAdjustedFont(12, true));
	    	            // map font named "font004" to font file "NotoSansSC-Regular.ttf" with encoding "Identity-H", must embed this font to the document
	            		rpt.setFontMapping("font004", QbReport.PLAIN, fontFold + "NotoSansSC-Regular.ttf", BaseFont.IDENTITY_H, true);
	            		// set rptcell font to "font004"
	    	            rptcell.setFont(font);
	            	}
	            	if (rptcell.getCustomID().equals("japanese")) {
	    	            font = FontTable.newFont("font005", Font.PLAIN, QbUtil.getAdjustedFont(15, true));
	            		rpt.setFontMapping("font005", QbReport.PLAIN, fontFold + "NotoSansJP-Regular.ttf", BaseFont.IDENTITY_H, true);
	    	            rptcell.setFont(font);
	            	}
	            	if (rptcell.getCustomID().equals("korean")) {
	    	            font = FontTable.newFont("font006", Font.BOLD, QbUtil.getAdjustedFont(10, true));
	            		rpt.setFontMapping("font006", QbReport.BOLD, fontFold + "NotoSansKR-Bold.ttf", BaseFont.IDENTITY_H, true);
	    	            rptcell.setFont(font);
	            	}
	            }
	            
	            rpt.refresh();
	            rpt.export(QbReport.PDF, exportPath);
	            
	            System.out.println("Done! PDF exported in " + exportPath + "!");

	        } catch (Exception e) {
	            e.printStackTrace();
	        }
	    }

}
